@@ -812,8 +812,8 @@ fwupd_guid_from_string(const gchar *guidstr,
 				    "GUID is not valid format, no dashes");
 		return FALSE;
 	}
-	if (strlen(split[0]) != 8 && strlen(split[1]) != 4 && strlen(split[2]) != 4 &&
-	    strlen(split[3]) != 4 && strlen(split[4]) != 12) {
+	if (strlen(split[0]) != 8 || strlen(split[1]) != 4 || strlen(split[2]) != 4 ||
+	    strlen(split[3]) != 4 || strlen(split[4]) != 12) {
 		g_set_error_literal(error,
 				    G_IO_ERROR,
 				    G_IO_ERROR_INVALID_DATA,
