@@ -138,6 +138,14 @@ G_BEGIN_DECLS
  * The D-Bus type signature string is 't' i.e. a unsigned 64 bit integer.
  **/
 #define FWUPD_RESULT_KEY_FLAGS "Flags"
+/**
+ * FWUPD_RESULT_KEY_REQUEST_FLAGS:
+ *
+ * Result key to represent RequestFlags
+ *
+ * The D-Bus type signature string is 't' i.e. a unsigned 64 bit integer.
+ **/
+#define FWUPD_RESULT_KEY_REQUEST_FLAGS "RequestFlags"
 /**
  * FWUPD_RESULT_KEY_FLASHES_LEFT:
  *
@@ -606,6 +614,22 @@ G_BEGIN_DECLS
  * The D-Bus type signature string is 'b' i.e. a boolean.
  **/
 #define FWUPD_RESULT_KEY_BIOS_SETTING_READ_ONLY "BiosSettingReadOnly"
+/**
+ * FWUPD_RESULT_KEY_KERNEL_CURRENT_VALUE:
+ *
+ * Result key to represent the current kernel setting.
+ *
+ * The D-Bus type signature string is 's' i.e. a string.
+ **/
+#define FWUPD_RESULT_KEY_KERNEL_CURRENT_VALUE "KernelCurrentValue"
+/**
+ * FWUPD_RESULT_KEY_KERNEL_TARGET_VALUE:
+ *
+ * Result key to represent the target kernel setting.
+ *
+ * The D-Bus type signature string is 's' i.e. a string.
+ **/
+#define FWUPD_RESULT_KEY_KERNEL_TARGET_VALUE "KernelTargetValue"
 /**
  * FWUPD_RESULT_KEY_DISTRO_ID:
  *
