@@ -2195,6 +2195,8 @@ fwupd_release_to_string(FwupdRelease *self)
 	fwupd_pad_kv_str(str, FWUPD_RESULT_KEY_APPSTREAM_ID, priv->appstream_id);
 	fwupd_pad_kv_str(str, FWUPD_RESULT_KEY_RELEASE_ID, priv->id);
 	fwupd_pad_kv_str(str, FWUPD_RESULT_KEY_REMOTE_ID, priv->remote_id);
+	fwupd_pad_kv_str(str, FWUPD_RESULT_KEY_NAME, priv->name);
+	fwupd_pad_kv_str(str, FWUPD_RESULT_KEY_NAME_VARIANT_SUFFIX, priv->name_variant_suffix);
 	fwupd_pad_kv_str(str, FWUPD_RESULT_KEY_SUMMARY, priv->summary);
 	fwupd_pad_kv_str(str, FWUPD_RESULT_KEY_DESCRIPTION, priv->description);
 	fwupd_pad_kv_str(str, FWUPD_RESULT_KEY_BRANCH, priv->branch);
