@@ -13,4 +13,7 @@ G_BEGIN_DECLS
 GVariant *
 fwupd_request_to_variant(FwupdRequest *self) G_GNUC_NON_NULL(1);
 
+void
+fwupd_request_emit_invalidate(FwupdRequest *self) G_GNUC_NON_NULL(1);
+
 G_END_DECLS
