@@ -8,6 +8,7 @@
 
 #include <glib-object.h>
 
+#include "fwupd-build.h"
 #include "fwupd-enums.h"
 
 G_BEGIN_DECLS
@@ -39,6 +40,8 @@ struct _FwupdSecurityAttrClass {
  * @FWUPD_SECURITY_ATTR_FLAG_ACTION_CONTACT_OEM:	Contact the firmware vendor for a update
  * @FWUPD_SECURITY_ATTR_FLAG_ACTION_CONFIG_FW:		Failure may be fixed by changing FW config
  * @FWUPD_SECURITY_ATTR_FLAG_ACTION_CONFIG_OS:		Failure may be fixed by changing OS config
+ * @FWUPD_SECURITY_ATTR_FLAG_CAN_FIX:			The failure can be automatically fixed
+ * @FWUPD_SECURITY_ATTR_FLAG_CAN_UNDO:			The fix can be automatically reverted
  *
  * The flags available for HSI attributes.
  **/
@@ -53,6 +56,8 @@ typedef enum {
 	FWUPD_SECURITY_ATTR_FLAG_ACTION_CONTACT_OEM = 1 << 11,
 	FWUPD_SECURITY_ATTR_FLAG_ACTION_CONFIG_FW = 1 << 12,
 	FWUPD_SECURITY_ATTR_FLAG_ACTION_CONFIG_OS = 1 << 13,
+	FWUPD_SECURITY_ATTR_FLAG_CAN_FIX = 1 << 14,
+	FWUPD_SECURITY_ATTR_FLAG_CAN_UNDO = 1 << 15,
 } FwupdSecurityAttrFlags;
 
 /**
@@ -124,93 +129,122 @@ typedef enum {
 FwupdSecurityAttr *
 fwupd_security_attr_new(const gchar *appstream_id);
 gchar *
-fwupd_security_attr_to_string(FwupdSecurityAttr *self);
+fwupd_security_attr_to_string(FwupdSecurityAttr *self) G_GNUC_NON_NULL(1);
 
 const gchar *
-fwupd_security_attr_get_bios_setting_id(FwupdSecurityAttr *self);
+fwupd_security_attr_get_bios_setting_id(FwupdSecurityAttr *self) G_GNUC_NON_NULL(1);
 void
-fwupd_security_attr_set_bios_setting_id(FwupdSecurityAttr *self, const gchar *id);
+fwupd_security_attr_set_bios_setting_id(FwupdSecurityAttr *self, const gchar *id)
+    G_GNUC_NON_NULL(1);
 const gchar *
-fwupd_security_attr_get_bios_setting_target_value(FwupdSecurityAttr *self);
+fwupd_security_attr_get_bios_setting_target_value(FwupdSecurityAttr *self) G_GNUC_NON_NULL(1);
 void
-fwupd_security_attr_set_bios_setting_target_value(FwupdSecurityAttr *self, const gchar *value);
+fwupd_security_attr_set_bios_setting_target_value(FwupdSecurityAttr *self, const gchar *value)
+    G_GNUC_NON_NULL(1);
 const gchar *
-fwupd_security_attr_get_bios_setting_current_value(FwupdSecurityAttr *self);
+fwupd_security_attr_get_bios_setting_current_value(FwupdSecurityAttr *self) G_GNUC_NON_NULL(1);
 void
-fwupd_security_attr_set_bios_setting_current_value(FwupdSecurityAttr *self, const gchar *value);
+fwupd_security_attr_set_bios_setting_current_value(FwupdSecurityAttr *self, const gchar *value)
+    G_GNUC_NON_NULL(1);
+const gchar *
+fwupd_security_attr_get_kernel_current_value(FwupdSecurityAttr *self) G_GNUC_NON_NULL(1);
+void
+fwupd_security_attr_set_kernel_current_value(FwupdSecurityAttr *self, const gchar *value)
+    G_GNUC_NON_NULL(1);
+const gchar *
+fwupd_security_attr_get_kernel_target_value(FwupdSecurityAttr *self) G_GNUC_NON_NULL(1);
+void
+fwupd_security_attr_set_kernel_target_value(FwupdSecurityAttr *self, const gchar *value)
+    G_GNUC_NON_NULL(1);
 
 const gchar *
-fwupd_security_attr_get_appstream_id(FwupdSecurityAttr *self);
+fwupd_security_attr_get_appstream_id(FwupdSecurityAttr *self) G_GNUC_NON_NULL(1);
 void
-fwupd_security_attr_set_appstream_id(FwupdSecurityAttr *self, const gchar *appstream_id);
+fwupd_security_attr_set_appstream_id(FwupdSecurityAttr *self, const gchar *appstream_id)
+    G_GNUC_NON_NULL(1);
 FwupdSecurityAttrLevel
-fwupd_security_attr_get_level(FwupdSecurityAttr *self);
+fwupd_security_attr_get_level(FwupdSecurityAttr *self) G_GNUC_NON_NULL(1);
 void
-fwupd_security_attr_set_level(FwupdSecurityAttr *self, FwupdSecurityAttrLevel level);
+fwupd_security_attr_set_level(FwupdSecurityAttr *self, FwupdSecurityAttrLevel level)
+    G_GNUC_NON_NULL(1);
 FwupdSecurityAttrResult
-fwupd_security_attr_get_result(FwupdSecurityAttr *self);
+fwupd_security_attr_get_result(FwupdSecurityAttr *self) G_GNUC_NON_NULL(1);
 void
-fwupd_security_attr_set_result(FwupdSecurityAttr *self, FwupdSecurityAttrResult result);
+fwupd_security_attr_set_result(FwupdSecurityAttr *self, FwupdSecurityAttrResult result)
+    G_GNUC_NON_NULL(1);
 FwupdSecurityAttrResult
-fwupd_security_attr_get_result_fallback(FwupdSecurityAttr *self);
+fwupd_security_attr_get_result_fallback(FwupdSecurityAttr *self) G_GNUC_NON_NULL(1);
 void
-fwupd_security_attr_set_result_fallback(FwupdSecurityAttr *self, FwupdSecurityAttrResult result);
+fwupd_security_attr_set_result_fallback(FwupdSecurityAttr *self, FwupdSecurityAttrResult result)
+    G_GNUC_NON_NULL(1);
 FwupdSecurityAttrResult
-fwupd_security_attr_get_result_success(FwupdSecurityAttr *self);
+fwupd_security_attr_get_result_success(FwupdSecurityAttr *self) G_GNUC_NON_NULL(1);
 void
-fwupd_security_attr_set_result_success(FwupdSecurityAttr *self, FwupdSecurityAttrResult result);
+fwupd_security_attr_set_result_success(FwupdSecurityAttr *self, FwupdSecurityAttrResult result)
+    G_GNUC_NON_NULL(1);
 const gchar *
-fwupd_security_attr_get_name(FwupdSecurityAttr *self);
+fwupd_security_attr_get_name(FwupdSecurityAttr *self) G_GNUC_NON_NULL(1);
 void
-fwupd_security_attr_set_name(FwupdSecurityAttr *self, const gchar *name);
+fwupd_security_attr_set_name(FwupdSecurityAttr *self, const gchar *name) G_GNUC_NON_NULL(1);
 const gchar *
-fwupd_security_attr_get_title(FwupdSecurityAttr *self);
+fwupd_security_attr_get_title(FwupdSecurityAttr *self) G_GNUC_NON_NULL(1);
 void
-fwupd_security_attr_set_title(FwupdSecurityAttr *self, const gchar *title);
+fwupd_security_attr_set_title(FwupdSecurityAttr *self, const gchar *title) G_GNUC_NON_NULL(1);
 const gchar *
-fwupd_security_attr_get_description(FwupdSecurityAttr *self);
+fwupd_security_attr_get_description(FwupdSecurityAttr *self) G_GNUC_NON_NULL(1);
 void
-fwupd_security_attr_set_description(FwupdSecurityAttr *self, const gchar *description);
+fwupd_security_attr_set_description(FwupdSecurityAttr *self, const gchar *description)
+    G_GNUC_NON_NULL(1);
 const gchar *
-fwupd_security_attr_get_plugin(FwupdSecurityAttr *self);
+fwupd_security_attr_get_plugin(FwupdSecurityAttr *self) G_GNUC_NON_NULL(1);
 void
-fwupd_security_attr_set_plugin(FwupdSecurityAttr *self, const gchar *plugin);
+fwupd_security_attr_set_plugin(FwupdSecurityAttr *self, const gchar *plugin) G_GNUC_NON_NULL(1);
 const gchar *
-fwupd_security_attr_get_url(FwupdSecurityAttr *self);
+fwupd_security_attr_get_url(FwupdSecurityAttr *self) G_GNUC_NON_NULL(1);
 void
-fwupd_security_attr_set_url(FwupdSecurityAttr *self, const gchar *url);
+fwupd_security_attr_set_url(FwupdSecurityAttr *self, const gchar *url) G_GNUC_NON_NULL(1);
 guint64
-fwupd_security_attr_get_created(FwupdSecurityAttr *self);
+fwupd_security_attr_get_created(FwupdSecurityAttr *self) G_GNUC_NON_NULL(1);
 void
-fwupd_security_attr_set_created(FwupdSecurityAttr *self, guint64 created);
+fwupd_security_attr_set_created(FwupdSecurityAttr *self, guint64 created) G_GNUC_NON_NULL(1);
 GPtrArray *
-fwupd_security_attr_get_obsoletes(FwupdSecurityAttr *self);
+fwupd_security_attr_get_obsoletes(FwupdSecurityAttr *self) G_GNUC_NON_NULL(1);
 void
-fwupd_security_attr_add_obsolete(FwupdSecurityAttr *self, const gchar *appstream_id);
+fwupd_security_attr_add_obsolete(FwupdSecurityAttr *self, const gchar *appstream_id)
+    G_GNUC_NON_NULL(1, 2);
 gboolean
-fwupd_security_attr_has_obsolete(FwupdSecurityAttr *self, const gchar *appstream_id);
+fwupd_security_attr_has_obsolete(FwupdSecurityAttr *self,
+				 const gchar *appstream_id) G_GNUC_WARN_UNUSED_RESULT
+    G_GNUC_NON_NULL(1, 2);
 GPtrArray *
-fwupd_security_attr_get_guids(FwupdSecurityAttr *self);
+fwupd_security_attr_get_guids(FwupdSecurityAttr *self) G_GNUC_NON_NULL(1);
 void
-fwupd_security_attr_add_guid(FwupdSecurityAttr *self, const gchar *guid);
+fwupd_security_attr_add_guid(FwupdSecurityAttr *self, const gchar *guid) G_GNUC_NON_NULL(1, 2);
 void
-fwupd_security_attr_add_guids(FwupdSecurityAttr *self, GPtrArray *guids);
+fwupd_security_attr_add_guids(FwupdSecurityAttr *self, GPtrArray *guids) G_GNUC_NON_NULL(1, 2);
 gboolean
-fwupd_security_attr_has_guid(FwupdSecurityAttr *self, const gchar *guid);
+fwupd_security_attr_has_guid(FwupdSecurityAttr *self, const gchar *guid) G_GNUC_WARN_UNUSED_RESULT
+    G_GNUC_NON_NULL(1, 2);
 const gchar *
-fwupd_security_attr_get_metadata(FwupdSecurityAttr *self, const gchar *key);
+fwupd_security_attr_get_metadata(FwupdSecurityAttr *self, const gchar *key) G_GNUC_NON_NULL(1, 2);
 void
-fwupd_security_attr_add_metadata(FwupdSecurityAttr *self, const gchar *key, const gchar *value);
+fwupd_security_attr_add_metadata(FwupdSecurityAttr *self, const gchar *key, const gchar *value)
+    G_GNUC_NON_NULL(1, 2);
 FwupdSecurityAttrFlags
-fwupd_security_attr_get_flags(FwupdSecurityAttr *self);
+fwupd_security_attr_get_flags(FwupdSecurityAttr *self) G_GNUC_NON_NULL(1);
 void
-fwupd_security_attr_set_flags(FwupdSecurityAttr *self, FwupdSecurityAttrFlags flags);
+fwupd_security_attr_set_flags(FwupdSecurityAttr *self, FwupdSecurityAttrFlags flags)
+    G_GNUC_NON_NULL(1);
 void
-fwupd_security_attr_add_flag(FwupdSecurityAttr *self, FwupdSecurityAttrFlags flag);
+fwupd_security_attr_add_flag(FwupdSecurityAttr *self, FwupdSecurityAttrFlags flag)
+    G_GNUC_NON_NULL(1);
 void
-fwupd_security_attr_remove_flag(FwupdSecurityAttr *self, FwupdSecurityAttrFlags flag);
+fwupd_security_attr_remove_flag(FwupdSecurityAttr *self, FwupdSecurityAttrFlags flag)
+    G_GNUC_NON_NULL(1);
 gboolean
-fwupd_security_attr_has_flag(FwupdSecurityAttr *self, FwupdSecurityAttrFlags flag);
+fwupd_security_attr_has_flag(FwupdSecurityAttr *self,
+			     FwupdSecurityAttrFlags flag) G_GNUC_WARN_UNUSED_RESULT
+    G_GNUC_NON_NULL(1);
 const gchar *
 fwupd_security_attr_flag_to_string(FwupdSecurityAttrFlags flag);
 FwupdSecurityAttrFlags
@@ -223,8 +257,8 @@ FwupdSecurityAttrResult
 fwupd_security_attr_result_from_string(const gchar *result);
 
 FwupdSecurityAttr *
-fwupd_security_attr_from_variant(GVariant *value);
+fwupd_security_attr_from_variant(GVariant *value) G_GNUC_NON_NULL(1);
 GPtrArray *
-fwupd_security_attr_array_from_variant(GVariant *value);
+fwupd_security_attr_array_from_variant(GVariant *value) G_GNUC_NON_NULL(1);
 
 G_END_DECLS
