@@ -13,10 +13,10 @@ fu_backend_load(FuBackend *self,
 		JsonObject *json_object,
 		const gchar *tag,
 		FuBackendLoadFlags flags,
-		GError **error);
+		GError **error) G_GNUC_NON_NULL(1, 2);
 gboolean
 fu_backend_save(FuBackend *self,
 		JsonBuilder *json_builder,
 		const gchar *tag,
 		FuBackendSaveFlags flags,
-		GError **error);
+		GError **error) G_GNUC_NON_NULL(1, 2);
