@@ -11,6 +11,7 @@
 #include "fu-byte-array.h"
 #include "fu-bytes.h"
 #include "fu-cfi-device.h"
+#include "fu-chunk-array.h"
 #include "fu-dump.h"
 #include "fu-mem.h"
 #include "fu-quirks.h"
@@ -221,7 +222,7 @@ fu_cfi_device_wait_for_status_cb(FuDevice *device, gpointer user_data, GError **
 			    FWUPD_ERROR_INTERNAL,
 			    "wanted 0x%x, got 0x%x",
 			    helper->value,
-			    buf[0x1] & helper->mask);
+			    (guint)(buf[0x1] & helper->mask));
 		return FALSE;
 	}
 
@@ -319,7 +320,13 @@ fu_cfi_device_setup(FuDevice *device, GError **error)
 	for (guint i = 0; i < flash_idsz; i += 2) {
 		g_autofree gchar *flash_id = g_strndup(priv->flash_id, i + 2);
 		fu_device_add_instance_str(device, "FLASHID", flash_id);
-		if (!fu_device_build_instance_id_quirk(device, error, "CFI", "FLASHID", NULL))
+		if (!fu_device_build_instance_id_full(device,
+						      FU_DEVICE_INSTANCE_FLAG_GENERIC |
+							  FU_DEVICE_INSTANCE_FLAG_QUIRKS,
+						      error,
+						      "CFI",
+						      "FLASHID",
+						      NULL))
 			return FALSE;
 	}
 
@@ -768,13 +775,16 @@ fu_cfi_device_write_page(FuCfiDevice *self, FuChunk *page, FuProgress *progress,
 }
 
 static gboolean
-fu_cfi_device_write_pages(FuCfiDevice *self, GPtrArray *pages, FuProgress *progress, GError **error)
+fu_cfi_device_write_pages(FuCfiDevice *self,
+			  FuChunkArray *pages,
+			  FuProgress *progress,
+			  GError **error)
 {
 	/* progress */
 	fu_progress_set_id(progress, G_STRLOC);
-	fu_progress_set_steps(progress, pages->len);
-	for (guint i = 0; i < pages->len; i++) {
-		FuChunk *page = g_ptr_array_index(pages, i);
+	fu_progress_set_steps(progress, fu_chunk_array_length(pages));
+	for (guint i = 0; i < fu_chunk_array_length(pages); i++) {
+		g_autoptr(FuChunk) page = fu_chunk_array_index(pages, i);
 		if (!fu_cfi_device_write_page(self, page, fu_progress_get_child(progress), error))
 			return FALSE;
 		fu_progress_step_done(progress);
@@ -865,7 +875,7 @@ fu_cfi_device_write_firmware(FuDevice *device,
 	FuCfiDevice *self = FU_CFI_DEVICE(device);
 	g_autoptr(GBytes) fw = NULL;
 	g_autoptr(GBytes) fw_verify = NULL;
-	g_autoptr(GPtrArray) pages = NULL;
+	g_autoptr(FuChunkArray) pages = NULL;
 	g_autoptr(FuDeviceLocker) locker = NULL;
 
 	/* open programmer */
@@ -896,7 +906,7 @@ fu_cfi_device_write_firmware(FuDevice *device,
 	fu_progress_step_done(progress);
 
 	/* write each block */
-	pages = fu_chunk_array_new_from_bytes(fw, 0x0, 0x0, fu_cfi_device_get_page_size(self));
+	pages = fu_chunk_array_new_from_bytes(fw, 0x0, fu_cfi_device_get_page_size(self));
 	if (!fu_cfi_device_write_pages(self, pages, fu_progress_get_child(progress), error)) {
 		g_prefix_error(error, "failed to write pages: ");
 		return FALSE;
