@@ -12,6 +12,7 @@
 #include "fu-firmware.h"
 
 void
-fu_chunk_export(FuChunk *self, FuFirmwareExportFlags flags, XbBuilderNode *bn);
+fu_chunk_export(FuChunk *self, FuFirmwareExportFlags flags, XbBuilderNode *bn)
+    G_GNUC_NON_NULL(1, 3);
 gboolean
-fu_chunk_build(FuChunk *self, XbNode *n, GError **error);
+fu_chunk_build(FuChunk *self, XbNode *n, GError **error) G_GNUC_NON_NULL(1, 2);
