@@ -170,8 +170,6 @@ fu_device_new(FuContext *ctx);
 #define fu_device_set_update_error(d, v)   fwupd_device_set_update_error(FWUPD_DEVICE(d), v)
 #define fu_device_add_vendor_id(d, v)	   fwupd_device_add_vendor_id(FWUPD_DEVICE(d), v)
 #define fu_device_add_protocol(d, v)	   fwupd_device_add_protocol(FWUPD_DEVICE(d), v)
-#define fu_device_set_version_lowest_raw(d, v)                                                     \
-	fwupd_device_set_version_lowest_raw(FWUPD_DEVICE(d), v)
 #define fu_device_set_version_bootloader_raw(d, v)                                                 \
 	fwupd_device_set_version_bootloader_raw(FWUPD_DEVICE(d), v)
 #define fu_device_set_version_build_date(d, v)                                                     \
@@ -540,6 +538,8 @@ typedef guint64 FuDeviceInternalFlags;
  *
  * Only use the metadata *checksum* to set device attributes.
  *
+ * NOTE: This will only work if the release and the device both have the same update protocol.
+ *
  * Since: 1.9.1
  */
 #define FU_DEVICE_INTERNAL_FLAG_MD_ONLY_CHECKSUM (1ull << 31)
@@ -750,6 +750,8 @@ fu_device_set_version_u32(FuDevice *self, guint32 version_raw) G_GNUC_NON_NULL(1
 void
 fu_device_set_version_u64(FuDevice *self, guint64 version_raw) G_GNUC_NON_NULL(1);
 void
+fu_device_set_version_lowest_raw(FuDevice *self, guint64 version_raw) G_GNUC_NON_NULL(1);
+void
 fu_device_inhibit(FuDevice *self, const gchar *inhibit_id, const gchar *reason)
     G_GNUC_NON_NULL(1, 2);
 void
