@@ -2,7 +2,7 @@
 // SPDX-License-Identifier: LGPL-2.1+
 
 #[repr(u16le)]
-enum ElfFileHeaderType {
+enum FuElfFileHeaderType {
     None = 0x00,
     Rel = 0x01,
     Exec = 0x02,
@@ -11,7 +11,7 @@ enum ElfFileHeaderType {
 }
 
 #[derive(ParseBytes, ValidateBytes)]
-struct ElfFileHeader64le {
+struct FuStructElfFileHeader64le {
     ei_magic: [char; 4] == "\x7F\x45\x4C\x46",
     ei_class: u8 == 0x2, // 64-bit format
     ei_data: u8 == 0x1, // LE
@@ -19,7 +19,7 @@ struct ElfFileHeader64le {
     ei_osabi: u8 = 0x3,
     ei_abiversion: u8,
     _ei_padding: [u8; 7] = 0x00000000000000,
-    type: ElfFileHeaderType,
+    type: FuElfFileHeaderType,
     machine: u16le,
     version: u32le == 0x1,
     entry: u64le,
@@ -35,7 +35,7 @@ struct ElfFileHeader64le {
 }
 
 #[derive(ParseBytes)]
-struct ElfProgramHeader64le {
+struct FuStructElfProgramHeader64le {
     flags: u32le,
     offset: u64le,
     vaddr: u64le,
@@ -47,7 +47,7 @@ struct ElfProgramHeader64le {
 }
 
 #[repr(u32le)]
-enum ElfSectionHeaderType {
+enum FuElfSectionHeaderType {
     Null = 0x0,
     Progbits = 0x1,
     Symtab = 0x2,
@@ -69,9 +69,9 @@ enum ElfSectionHeaderType {
 }
 
 #[derive(ParseBytes)]
-struct ElfSectionHeader64le {
+struct FuStructElfSectionHeader64le {
     name: u32le,
-    type: ElfSectionHeaderType,
+    type: FuElfSectionHeaderType,
     flags: u64le,
     addr: u64le,
     offset: u64le,
