@@ -19,8 +19,9 @@ struct _FuFdtFirmwareClass {
 FuFirmware *
 fu_fdt_firmware_new(void);
 guint32
-fu_fdt_firmware_get_cpuid(FuFdtFirmware *self);
+fu_fdt_firmware_get_cpuid(FuFdtFirmware *self) G_GNUC_NON_NULL(1);
 void
-fu_fdt_firmware_set_cpuid(FuFdtFirmware *self, guint32 cpuid);
+fu_fdt_firmware_set_cpuid(FuFdtFirmware *self, guint32 cpuid) G_GNUC_NON_NULL(1);
 FuFdtImage *
-fu_fdt_firmware_get_image_by_path(FuFdtFirmware *self, const gchar *path, GError **error);
+fu_fdt_firmware_get_image_by_path(FuFdtFirmware *self, const gchar *path, GError **error)
+    G_GNUC_NON_NULL(1);
