@@ -223,133 +223,148 @@ fu_firmware_new(void);
 FuFirmware *
 fu_firmware_new_from_bytes(GBytes *fw);
 FuFirmware *
-fu_firmware_new_from_gtypes(GBytes *fw, gsize offset, FwupdInstallFlags flags, GError **error, ...);
+fu_firmware_new_from_gtypes(GBytes *fw, gsize offset, FwupdInstallFlags flags, GError **error, ...)
+    G_GNUC_NON_NULL(1);
 gchar *
-fu_firmware_to_string(FuFirmware *self);
+fu_firmware_to_string(FuFirmware *self) G_GNUC_NON_NULL(1);
 void
-fu_firmware_export(FuFirmware *self, FuFirmwareExportFlags flags, XbBuilderNode *bn);
+fu_firmware_export(FuFirmware *self, FuFirmwareExportFlags flags, XbBuilderNode *bn)
+    G_GNUC_NON_NULL(1, 3);
 gchar *
-fu_firmware_export_to_xml(FuFirmware *self, FuFirmwareExportFlags flags, GError **error);
+fu_firmware_export_to_xml(FuFirmware *self, FuFirmwareExportFlags flags, GError **error)
+    G_GNUC_NON_NULL(1);
 const gchar *
-fu_firmware_get_version(FuFirmware *self);
+fu_firmware_get_version(FuFirmware *self) G_GNUC_NON_NULL(1);
 void
-fu_firmware_set_version(FuFirmware *self, const gchar *version);
+fu_firmware_set_version(FuFirmware *self, const gchar *version) G_GNUC_NON_NULL(1);
 guint64
-fu_firmware_get_version_raw(FuFirmware *self);
+fu_firmware_get_version_raw(FuFirmware *self) G_GNUC_NON_NULL(1);
 void
-fu_firmware_set_version_raw(FuFirmware *self, guint64 version_raw);
+fu_firmware_set_version_raw(FuFirmware *self, guint64 version_raw) G_GNUC_NON_NULL(1);
 void
-fu_firmware_add_flag(FuFirmware *firmware, FuFirmwareFlags flag);
+fu_firmware_add_flag(FuFirmware *firmware, FuFirmwareFlags flag) G_GNUC_NON_NULL(1);
 gboolean
-fu_firmware_has_flag(FuFirmware *firmware, FuFirmwareFlags flag);
+fu_firmware_has_flag(FuFirmware *firmware, FuFirmwareFlags flag) G_GNUC_NON_NULL(1);
 const gchar *
-fu_firmware_get_filename(FuFirmware *self);
+fu_firmware_get_filename(FuFirmware *self) G_GNUC_NON_NULL(1);
 void
-fu_firmware_set_filename(FuFirmware *self, const gchar *filename);
+fu_firmware_set_filename(FuFirmware *self, const gchar *filename) G_GNUC_NON_NULL(1);
 const gchar *
-fu_firmware_get_id(FuFirmware *self);
+fu_firmware_get_id(FuFirmware *self) G_GNUC_NON_NULL(1);
 void
-fu_firmware_set_id(FuFirmware *self, const gchar *id);
+fu_firmware_set_id(FuFirmware *self, const gchar *id) G_GNUC_NON_NULL(1);
 guint64
-fu_firmware_get_addr(FuFirmware *self);
+fu_firmware_get_addr(FuFirmware *self) G_GNUC_NON_NULL(1);
 void
-fu_firmware_set_addr(FuFirmware *self, guint64 addr);
+fu_firmware_set_addr(FuFirmware *self, guint64 addr) G_GNUC_NON_NULL(1);
 guint64
-fu_firmware_get_offset(FuFirmware *self);
+fu_firmware_get_offset(FuFirmware *self) G_GNUC_NON_NULL(1);
 void
-fu_firmware_set_offset(FuFirmware *self, guint64 offset);
+fu_firmware_set_offset(FuFirmware *self, guint64 offset) G_GNUC_NON_NULL(1);
 gsize
-fu_firmware_get_size(FuFirmware *self);
+fu_firmware_get_size(FuFirmware *self) G_GNUC_NON_NULL(1);
 void
-fu_firmware_set_size(FuFirmware *self, gsize size);
+fu_firmware_set_size(FuFirmware *self, gsize size) G_GNUC_NON_NULL(1);
 void
-fu_firmware_set_images_max(FuFirmware *self, guint images_max);
+fu_firmware_set_size_max(FuFirmware *self, gsize size_max) G_GNUC_NON_NULL(1);
+gsize
+fu_firmware_get_size_max(FuFirmware *self) G_GNUC_NON_NULL(1);
+void
+fu_firmware_set_images_max(FuFirmware *self, guint images_max) G_GNUC_NON_NULL(1);
 guint
-fu_firmware_get_images_max(FuFirmware *self);
+fu_firmware_get_images_max(FuFirmware *self) G_GNUC_NON_NULL(1);
 guint64
-fu_firmware_get_idx(FuFirmware *self);
+fu_firmware_get_idx(FuFirmware *self) G_GNUC_NON_NULL(1);
 void
-fu_firmware_set_idx(FuFirmware *self, guint64 idx);
+fu_firmware_set_idx(FuFirmware *self, guint64 idx) G_GNUC_NON_NULL(1);
 GBytes *
-fu_firmware_get_bytes(FuFirmware *self, GError **error);
+fu_firmware_get_bytes(FuFirmware *self, GError **error) G_GNUC_NON_NULL(1);
 GBytes *
-fu_firmware_get_bytes_with_patches(FuFirmware *self, GError **error);
+fu_firmware_get_bytes_with_patches(FuFirmware *self, GError **error) G_GNUC_NON_NULL(1);
 void
-fu_firmware_set_bytes(FuFirmware *self, GBytes *bytes);
+fu_firmware_set_bytes(FuFirmware *self, GBytes *bytes) G_GNUC_NON_NULL(1);
 guint8
-fu_firmware_get_alignment(FuFirmware *self);
+fu_firmware_get_alignment(FuFirmware *self) G_GNUC_NON_NULL(1);
 void
-fu_firmware_set_alignment(FuFirmware *self, guint8 alignment);
+fu_firmware_set_alignment(FuFirmware *self, guint8 alignment) G_GNUC_NON_NULL(1);
 void
-fu_firmware_add_chunk(FuFirmware *self, FuChunk *chk);
+fu_firmware_add_chunk(FuFirmware *self, FuChunk *chk) G_GNUC_NON_NULL(1);
 GPtrArray *
-fu_firmware_get_chunks(FuFirmware *self, GError **error);
+fu_firmware_get_chunks(FuFirmware *self, GError **error) G_GNUC_NON_NULL(1);
 FuFirmware *
-fu_firmware_get_parent(FuFirmware *self);
+fu_firmware_get_parent(FuFirmware *self) G_GNUC_NON_NULL(1);
 void
-fu_firmware_set_parent(FuFirmware *self, FuFirmware *parent);
+fu_firmware_set_parent(FuFirmware *self, FuFirmware *parent) G_GNUC_NON_NULL(1);
 
 gboolean
 fu_firmware_tokenize(FuFirmware *self, GBytes *fw, FwupdInstallFlags flags, GError **error)
-    G_GNUC_WARN_UNUSED_RESULT;
+    G_GNUC_WARN_UNUSED_RESULT G_GNUC_NON_NULL(1, 2);
 gboolean
-fu_firmware_build(FuFirmware *self, XbNode *n, GError **error) G_GNUC_WARN_UNUSED_RESULT;
+fu_firmware_build(FuFirmware *self, XbNode *n, GError **error) G_GNUC_WARN_UNUSED_RESULT
+    G_GNUC_NON_NULL(1, 2);
 gboolean
 fu_firmware_build_from_xml(FuFirmware *self,
 			   const gchar *xml,
-			   GError **error) G_GNUC_WARN_UNUSED_RESULT;
+			   GError **error) G_GNUC_WARN_UNUSED_RESULT G_GNUC_NON_NULL(1, 2);
 gboolean
 fu_firmware_parse(FuFirmware *self, GBytes *fw, FwupdInstallFlags flags, GError **error)
-    G_GNUC_WARN_UNUSED_RESULT;
+    G_GNUC_WARN_UNUSED_RESULT G_GNUC_NON_NULL(1);
 gboolean
 fu_firmware_parse_file(FuFirmware *self, GFile *file, FwupdInstallFlags flags, GError **error)
-    G_GNUC_WARN_UNUSED_RESULT;
+    G_GNUC_WARN_UNUSED_RESULT G_GNUC_NON_NULL(1, 2);
 gboolean
 fu_firmware_parse_full(FuFirmware *self,
 		       GBytes *fw,
 		       gsize offset,
 		       FwupdInstallFlags flags,
-		       GError **error) G_GNUC_WARN_UNUSED_RESULT;
+		       GError **error) G_GNUC_WARN_UNUSED_RESULT G_GNUC_NON_NULL(1, 2);
 GBytes *
-fu_firmware_write(FuFirmware *self, GError **error) G_GNUC_WARN_UNUSED_RESULT;
+fu_firmware_write(FuFirmware *self, GError **error) G_GNUC_WARN_UNUSED_RESULT G_GNUC_NON_NULL(1);
 GBytes *
 fu_firmware_write_chunk(FuFirmware *self, guint64 address, guint64 chunk_sz_max, GError **error)
-    G_GNUC_WARN_UNUSED_RESULT;
+    G_GNUC_WARN_UNUSED_RESULT G_GNUC_NON_NULL(1);
 gboolean
-fu_firmware_write_file(FuFirmware *self, GFile *file, GError **error) G_GNUC_WARN_UNUSED_RESULT;
+fu_firmware_write_file(FuFirmware *self, GFile *file, GError **error) G_GNUC_WARN_UNUSED_RESULT
+    G_GNUC_NON_NULL(1, 2);
 gchar *
-fu_firmware_get_checksum(FuFirmware *self, GChecksumType csum_kind, GError **error);
+fu_firmware_get_checksum(FuFirmware *self, GChecksumType csum_kind, GError **error)
+    G_GNUC_NON_NULL(1);
 gboolean
 fu_firmware_check_compatible(FuFirmware *self,
 			     FuFirmware *other,
 			     FwupdInstallFlags flags,
-			     GError **error);
+			     GError **error) G_GNUC_NON_NULL(1, 2);
 
 void
-fu_firmware_add_image(FuFirmware *self, FuFirmware *img);
+fu_firmware_add_image(FuFirmware *self, FuFirmware *img) G_GNUC_NON_NULL(1, 2);
 gboolean
-fu_firmware_add_image_full(FuFirmware *self, FuFirmware *img, GError **error);
+fu_firmware_add_image_full(FuFirmware *self, FuFirmware *img, GError **error) G_GNUC_NON_NULL(1, 2);
 gboolean
-fu_firmware_remove_image(FuFirmware *self, FuFirmware *img, GError **error);
+fu_firmware_remove_image(FuFirmware *self, FuFirmware *img, GError **error) G_GNUC_NON_NULL(1, 2);
 gboolean
-fu_firmware_remove_image_by_idx(FuFirmware *self, guint64 idx, GError **error);
+fu_firmware_remove_image_by_idx(FuFirmware *self, guint64 idx, GError **error) G_GNUC_NON_NULL(1);
 gboolean
-fu_firmware_remove_image_by_id(FuFirmware *self, const gchar *id, GError **error);
+fu_firmware_remove_image_by_id(FuFirmware *self, const gchar *id, GError **error)
+    G_GNUC_NON_NULL(1);
 GPtrArray *
-fu_firmware_get_images(FuFirmware *self);
+fu_firmware_get_images(FuFirmware *self) G_GNUC_NON_NULL(1);
 FuFirmware *
-fu_firmware_get_image_by_id(FuFirmware *self, const gchar *id, GError **error);
+fu_firmware_get_image_by_id(FuFirmware *self, const gchar *id, GError **error) G_GNUC_NON_NULL(1);
 GBytes *
-fu_firmware_get_image_by_id_bytes(FuFirmware *self, const gchar *id, GError **error);
+fu_firmware_get_image_by_id_bytes(FuFirmware *self, const gchar *id, GError **error)
+    G_GNUC_NON_NULL(1);
 FuFirmware *
-fu_firmware_get_image_by_idx(FuFirmware *self, guint64 idx, GError **error);
+fu_firmware_get_image_by_idx(FuFirmware *self, guint64 idx, GError **error) G_GNUC_NON_NULL(1);
 GBytes *
-fu_firmware_get_image_by_idx_bytes(FuFirmware *self, guint64 idx, GError **error);
+fu_firmware_get_image_by_idx_bytes(FuFirmware *self, guint64 idx, GError **error)
+    G_GNUC_NON_NULL(1);
 FuFirmware *
-fu_firmware_get_image_by_gtype(FuFirmware *self, GType gtype, GError **error);
+fu_firmware_get_image_by_gtype(FuFirmware *self, GType gtype, GError **error) G_GNUC_NON_NULL(1);
 GBytes *
-fu_firmware_get_image_by_gtype_bytes(FuFirmware *self, GType gtype, GError **error);
+fu_firmware_get_image_by_gtype_bytes(FuFirmware *self, GType gtype, GError **error)
+    G_GNUC_NON_NULL(1);
 FuFirmware *
-fu_firmware_get_image_by_checksum(FuFirmware *self, const gchar *checksum, GError **error);
+fu_firmware_get_image_by_checksum(FuFirmware *self, const gchar *checksum, GError **error)
+    G_GNUC_NON_NULL(1, 2);
 void
-fu_firmware_add_patch(FuFirmware *self, gsize offset, GBytes *blob);
+fu_firmware_add_patch(FuFirmware *self, gsize offset, GBytes *blob) G_GNUC_NON_NULL(1, 3);
