@@ -257,7 +257,6 @@ fu_ihex_firmware_parse(FuFirmware *firmware,
 	guint32 addr_last = 0x0;
 	guint32 img_addr = G_MAXUINT32;
 	guint32 seg_addr = 0x0;
-	gboolean is_debug = g_getenv("FU_IHEX_FIRMWARE_VERBOSE") != NULL;
 	g_autoptr(GBytes) img_bytes = NULL;
 	g_autoptr(GByteArray) buf = g_byte_array_new();
 
@@ -269,11 +268,9 @@ fu_ihex_firmware_parse(FuFirmware *firmware,
 		guint32 len_hole;
 
 		/* debug */
-		if (is_debug) {
-			g_debug("%s:", fu_ihex_firmware_record_type_to_string(rcd->record_type));
-			g_debug("  length:\t0x%02x", rcd->data->len);
-			g_debug("  addr:\t0x%08x", addr);
-		}
+		g_debug("%s:", fu_ihex_firmware_record_type_to_string(rcd->record_type));
+		g_debug("length:\t0x%02x", rcd->data->len);
+		g_debug("addr:\t0x%08x", addr);
 
 		/* sanity check */
 		if (rcd->record_type != FU_IHEX_FIRMWARE_RECORD_TYPE_EOF && rcd->data->len == 0) {
@@ -374,8 +371,7 @@ fu_ihex_firmware_parse(FuFirmware *firmware,
 						    error))
 				return FALSE;
 			abs_addr = (guint32)addr16 << 16;
-			if (is_debug)
-				g_debug("  abs_addr:\t0x%02x on line %u", abs_addr, rcd->ln);
+			g_debug("abs_addr:\t0x%02x on line %u", abs_addr, rcd->ln);
 			break;
 		case FU_IHEX_FIRMWARE_RECORD_TYPE_START_LINEAR:
 			if (!fu_memread_uint32_safe(rcd->data->data,
@@ -385,8 +381,7 @@ fu_ihex_firmware_parse(FuFirmware *firmware,
 						    G_BIG_ENDIAN,
 						    error))
 				return FALSE;
-			if (is_debug)
-				g_debug("  abs_addr:\t0x%08x on line %u", abs_addr, rcd->ln);
+			g_debug("abs_addr:\t0x%08x on line %u", abs_addr, rcd->ln);
 			break;
 		case FU_IHEX_FIRMWARE_RECORD_TYPE_EXTENDED_SEGMENT:
 			if (!fu_memread_uint16_safe(rcd->data->data,
@@ -398,8 +393,7 @@ fu_ihex_firmware_parse(FuFirmware *firmware,
 				return FALSE;
 			/* segment base address, so ~1Mb addressable */
 			seg_addr = (guint32)addr16 * 16;
-			if (is_debug)
-				g_debug("  seg_addr:\t0x%08x on line %u", seg_addr, rcd->ln);
+			g_debug("seg_addr:\t0x%08x on line %u", seg_addr, rcd->ln);
 			break;
 		case FU_IHEX_FIRMWARE_RECORD_TYPE_START_SEGMENT:
 			/* initial content of the CS:IP registers */
@@ -410,8 +404,7 @@ fu_ihex_firmware_parse(FuFirmware *firmware,
 						    G_BIG_ENDIAN,
 						    error))
 				return FALSE;
-			if (is_debug)
-				g_debug("  seg_addr:\t0x%02x on line %u", seg_addr, rcd->ln);
+			g_debug("seg_addr:\t0x%02x on line %u", seg_addr, rcd->ln);
 			break;
 		case FU_IHEX_FIRMWARE_RECORD_TYPE_SIGNATURE:
 			if (got_sig) {
@@ -428,7 +421,8 @@ fu_ihex_firmware_parse(FuFirmware *firmware,
 				g_autoptr(FuFirmware) img_sig =
 				    fu_firmware_new_from_bytes(data_sig);
 				fu_firmware_set_id(img_sig, FU_FIRMWARE_ID_SIGNATURE);
-				fu_firmware_add_image(firmware, img_sig);
+				if (!fu_firmware_add_image_full(firmware, img_sig, error))
+					return FALSE;
 			}
 			got_sig = TRUE;
 			break;
@@ -519,9 +513,10 @@ fu_ihex_firmware_image_to_string(GBytes *bytes,
 	return TRUE;
 }
 
-static GBytes *
+static GByteArray *
 fu_ihex_firmware_write(FuFirmware *firmware, GError **error)
 {
+	g_autoptr(GByteArray) buf = g_byte_array_new();
 	g_autoptr(GBytes) fw = NULL;
 	g_autoptr(FuFirmware) img_sig = NULL;
 	g_autoptr(GString) str = g_string_new("");
@@ -553,7 +548,8 @@ fu_ihex_firmware_write(FuFirmware *firmware, GError **error)
 
 	/* add EOF */
 	fu_ihex_firmware_emit_chunk(str, 0x0, FU_IHEX_FIRMWARE_RECORD_TYPE_EOF, NULL, 0);
-	return g_bytes_new(str->str, str->len);
+	g_byte_array_append(buf, (const guint8 *)str->str, str->len);
+	return g_steal_pointer(&buf);
 }
 
 static void
@@ -572,6 +568,7 @@ fu_ihex_firmware_init(FuIhexFirmware *self)
 	priv->padding_value = 0x00; /* chosen as we can't write 0xffff to PIC14 */
 	priv->records = g_ptr_array_new_with_free_func((GFreeFunc)fu_ihex_firmware_record_free);
 	fu_firmware_add_flag(FU_FIRMWARE(self), FU_FIRMWARE_FLAG_HAS_CHECKSUM);
+	fu_firmware_set_images_max(FU_FIRMWARE(self), 10);
 }
 
 static void
