@@ -2,7 +2,7 @@
 // SPDX-License-Identifier: LGPL-2.1+
 
 #[derive(ParseBytes, ValidateBytes)]
-struct PeDosHeader {
+struct FuStructPeDosHeader {
     magic: u16le == 0x5A4D,
     _cblp: u16le = 0x90,
     _cp: u16le = 0x3,
@@ -25,7 +25,7 @@ struct PeDosHeader {
 }
 
 #[repr(u16le)]
-enum PeCoffMachine {
+enum FuPeCoffMachine {
     Unknown,
     Alpha = 0x184,
     Alpha64 = 0x284,
@@ -58,7 +58,7 @@ enum PeCoffMachine {
 }
 
 #[repr(u16le)]
-enum PeCoffMagic {
+enum FuPeCoffMagic {
     Pe32 = 0x10b,
     Pe32Plus = 0x20b,
 }
@@ -82,9 +82,9 @@ enum FuCoffSubsystem {
 }
 
 #[derive(ParseBytes)]
-struct PeCoffFileHeader {
+struct FuStructPeCoffFileHeader {
     signature: u32le == 0x4550, // "PE\0\0"
-    machine: PeCoffMachine = Amd64,
+    machine: FuPeCoffMachine = Amd64,
     number_of_sections: u16le,
     _time_date_stamp: u32le,
     pointer_to_symbol_table: u32le,
@@ -94,8 +94,8 @@ struct PeCoffFileHeader {
 }
 
 #[derive(ParseBytes)]
-struct PeCoffOptionalHeader64 {
-    magic: PeCoffMagic = Pe32Plus,
+struct FuStructPeCoffOptionalHeader64 {
+    magic: FuPeCoffMagic = Pe32Plus,
     _major_linker_version: u8 = 0x0e,
     _minor_linker_version: u8 = 0x0e,
     size_of_code: u32le,
@@ -126,7 +126,7 @@ struct PeCoffOptionalHeader64 {
     number_of_rva_and_sizes: u32le,
 }
 
-struct PeCoffSymbol {
+struct FuStructPeCoffSymbol {
     name: [char; 8],
     value: u32le,
     section_number: u16le,
@@ -136,7 +136,7 @@ struct PeCoffSymbol {
 }
 
 #[derive(ParseBytes)]
-struct PeCoffSection {
+struct FuStructPeCoffSection {
     name: [char; 8],
     virtual_size: u32le,
     virtual_address: u32le,
