@@ -221,7 +221,8 @@ fu_plugin_cache_remove(FuPlugin *self, const gchar *id)
 	g_return_if_fail(id != NULL);
 	if (priv->cache == NULL)
 		return;
-	g_hash_table_remove(priv->cache, id);
+	if (g_hash_table_remove(priv->cache, id))
+		g_debug("removed %s object %s", fu_plugin_get_name(self), id);
 }
 
 /**
@@ -535,7 +536,8 @@ fu_plugin_device_add(FuPlugin *self, FuDevice *device)
 	}
 
 	g_debug("emit added from %s: %s", fu_plugin_get_name(self), fu_device_get_id(device));
-	fu_device_set_created(device, (guint64)g_get_real_time() / G_USEC_PER_SEC);
+	if (fu_device_get_created(device) == 0)
+		fu_device_set_created(device, (guint64)g_get_real_time() / G_USEC_PER_SEC);
 	fu_device_set_plugin(device, fu_plugin_get_name(self));
 	g_signal_emit(self, signals[SIGNAL_DEVICE_ADDED], 0, device);
 
