@@ -246,6 +246,14 @@ fu_quirks_add_possible_key(FuQuirks *self, const gchar *possible_key) G_GNUC_NON
  * Since: 1.3.7
  **/
 #define FU_QUIRKS_GTYPE "GType"
+/**
+ * FU_QUIRKS_PROXY_GTYPE:
+ *
+ * The quirk key for the custom proxy GType, e.g. `FuCcgxHidDevice`.
+ *
+ * Since: 1.9.15
+ **/
+#define FU_QUIRKS_PROXY_GTYPE "ProxyGType"
 /**
  * FU_QUIRKS_FIRMWARE_GTYPE:
  *
