@@ -2,7 +2,7 @@
 // SPDX-License-Identifier: LGPL-2.1+
 
 #[derive(New, Parse)]
-struct SmbiosEp32 {
+struct FuStructSmbiosEp32 {
     anchor_str: [char; 4],
     entry_point_csum: u8,
     entry_point_len: u8,
@@ -19,7 +19,7 @@ struct SmbiosEp32 {
     smbios_bcd_rev: u8,
 }
 #[derive(New, Parse)]
-struct SmbiosEp64 {
+struct FuStructSmbiosEp64 {
     anchor_str: [char; 5],
     entry_point_csum: u8,
     entry_point_len: u8,
@@ -32,7 +32,7 @@ struct SmbiosEp64 {
     structure_table_addr: u64le,
 }
 #[derive(New, Parse)]
-struct SmbiosStructure {
+struct FuStructSmbiosStructure {
     type: u8,
     length: u8,
     handle: u16le,
