@@ -92,6 +92,86 @@ fu_strtoull(const gchar *str, guint64 *value, guint64 min, guint64 max, GError *
 	return TRUE;
 }
 
+/**
+ * fu_strtoll:
+ * @str: a string, e.g. `0x1234`, `-12345`
+ * @value: (out) (nullable): parsed value
+ * @min: minimum acceptable value, typically 0
+ * @max: maximum acceptable value, typically G_MAXINT64
+ * @error: (nullable): optional return location for an error
+ *
+ * Converts a string value to an integer. Values are assumed base 10, unless
+ * prefixed with "0x" where they are parsed as base 16.
+ *
+ * Returns: %TRUE if the value was parsed correctly, or %FALSE for error
+ *
+ * Since: 1.9.7
+ **/
+gboolean
+fu_strtoll(const gchar *str, gint64 *value, gint64 min, gint64 max, GError **error)
+{
+	gchar *endptr = NULL;
+	gint64 value_tmp;
+	guint base = 10;
+
+	/* sanity check */
+	if (str == NULL) {
+		g_set_error_literal(error,
+				    G_IO_ERROR,
+				    G_IO_ERROR_INVALID_DATA,
+				    "cannot parse NULL");
+		return FALSE;
+	}
+
+	/* detect hex */
+	if (g_str_has_prefix(str, "0x")) {
+		str += 2;
+		base = 16;
+	}
+
+	/* convert */
+	value_tmp = g_ascii_strtoll(str, &endptr, base);
+	if ((gsize)(endptr - str) != strlen(str) && *endptr != '\n') {
+		g_set_error(error, G_IO_ERROR, G_IO_ERROR_INVALID_DATA, "cannot parse %s", str);
+		return FALSE;
+	}
+
+	/* overflow check */
+	if (value_tmp == G_MAXINT64) {
+		g_set_error(error,
+			    G_IO_ERROR,
+			    G_IO_ERROR_INVALID_DATA,
+			    "cannot parse %s as caused overflow",
+			    str);
+		return FALSE;
+	}
+
+	/* range check */
+	if (value_tmp < min) {
+		g_set_error(error,
+			    G_IO_ERROR,
+			    G_IO_ERROR_INVALID_DATA,
+			    "value %" G_GINT64_FORMAT " was below minimum %" G_GINT64_FORMAT,
+			    value_tmp,
+			    min);
+		return FALSE;
+	}
+	if (value_tmp > max) {
+		g_set_error(error,
+			    G_IO_ERROR,
+			    G_IO_ERROR_INVALID_DATA,
+			    "value %" G_GINT64_FORMAT " was above maximum %" G_GINT64_FORMAT,
+			    value_tmp,
+			    max);
+		return FALSE;
+	}
+
+	/* success */
+	if (value != NULL)
+		*value = value_tmp;
+	return TRUE;
+}
+
 /**
  * fu_strtobool:
  * @str: a string, e.g. `true`
@@ -173,6 +253,36 @@ fu_strstrip(const gchar *str)
 	return g_strndup(str + head, tail - head + 1);
 }
 
+/**
+ * fu_string_strip:
+ * @str: a #GString, e.g. ` test `
+ *
+ * Removes leading and trailing whitespace from a mutable string.
+ *
+ * Since: 2.0.17
+ **/
+void
+fu_string_strip(GString *str)
+{
+	guint i;
+
+	/* leading whitespace */
+	for (i = 0; i < str->len; i++) {
+		if (!g_ascii_isspace(str->str[i]))
+			break;
+	}
+	if (i > 0)
+		g_string_erase(str, 0, i);
+
+	/* trailing whitespace */
+	for (i = 0; i < str->len; i++) {
+		if (!g_ascii_isspace(str->str[str->len - (i + 1)]))
+			break;
+	}
+	if (i < str->len)
+		g_string_truncate(str, str->len - i);
+}
+
 /**
  * fu_strdup:
  * @str: a string, e.g. ` test `
@@ -500,6 +610,54 @@ fu_strjoin(const gchar *separator, GPtrArray *array)
 	return g_strjoinv(separator, (gchar **)strv);
 }
 
+/**
+ * fu_strpassmask:
+ * @str: (nullable): a string to make safe for printing
+ *
+ * Hides password strings encoded in HTTP requests.
+ *
+ * Returns: a string
+ *
+ * Since: 1.9.10
+ **/
+gchar *
+fu_strpassmask(const gchar *str)
+{
+	g_autoptr(GString) tmp = g_string_new(str);
+	if (tmp->str != NULL && g_strstr_len(tmp->str, -1, "@") != NULL &&
+	    g_strstr_len(tmp->str, -1, ":") != NULL) {
+		gboolean is_password = FALSE;
+		gboolean is_url = FALSE;
+		for (guint i = 0; i < tmp->len; i++) {
+			const gchar *url_prefixes[] = {"http://", "https://", NULL};
+			for (guint j = 0; url_prefixes[j] != NULL; j++) {
+				if (g_str_has_prefix(tmp->str + i, url_prefixes[j])) {
+					is_url = TRUE;
+					i += strlen(url_prefixes[j]);
+					break;
+				}
+			}
+			if (tmp->str[i] == ' ' || tmp->str[i] == '@' || tmp->str[i] == '/') {
+				is_url = FALSE;
+				is_password = FALSE;
+				continue;
+			}
+			if (is_url && tmp->str[i] == ':') {
+				is_password = TRUE;
+				continue;
+			}
+			if (is_url && is_password) {
+				if (tmp->str[i] == '@') {
+					is_password = FALSE;
+					continue;
+				}
+				tmp->str[i] = 'X';
+			}
+		}
+	}
+	return g_string_free(g_steal_pointer(&tmp), FALSE);
+}
+
 /**
  * fu_utf16_to_utf8_byte_array:
  * @array: a #GByteArray
