@@ -1,8 +1,8 @@
 // Copyright (C) 2023 Richard Hughes <richard@hughsie.com>
 // SPDX-License-Identifier: LGPL-2.1+
 
-#[derive(New, Validate, Parse)]
-struct Ds20 {
+#[derive(New, ParseBytes)]
+struct FuStructDs20 {
     _reserved: u8,
     guid: Guid,
     platform_ver: u32le,
@@ -10,8 +10,8 @@ struct Ds20 {
     vendor_code: u8,
     alt_code: u8,
 }
-#[derive(New, Validate, Parse)]
-struct MsDs20 {
+#[derive(New, ParseBytes)]
+struct FuStructMsDs20 {
     size: u16le,
     type: u16le,
 }
