@@ -1,7 +1,7 @@
 // Copyright (C) 2024 Algoltek, Inc.
 // SPDX-License-Identifier: LGPL-2.1+
 
-enum AlgoltekCmd {
+enum FuAlgoltekCmd {
     Rdr = 0x06,
     Wrr,
     Rdv,
@@ -14,7 +14,7 @@ enum AlgoltekCmd {
 }
 
 #[derive(Getters,ValidateBytes)]
-struct AlgoltekProductIdentity {
+struct FuStructAlgoltekProductIdentity {
     header_len: u8,
     header: u64le == 0x4B45544C4F474C41, // 'A' 'L' 'G' 'O' 'L' 'T' 'E' 'K'
     product_name_len: u8,
@@ -24,7 +24,7 @@ struct AlgoltekProductIdentity {
 }
 
 #[derive(New)]
-struct AlgoltekCmdAddressPkt {
+struct FuStructAlgoltekCmdAddressPkt {
     len: u8,
     cmd: u8,
     address: u16be,
@@ -34,7 +34,7 @@ struct AlgoltekCmdAddressPkt {
 }
 
 #[derive(New)]
-struct AlgoltekCmdTransferPkt {
+struct FuStructAlgoltekCmdTransferPkt {
     len: u8,
     cmd: u8,
     address: u16be,
