@@ -2,7 +2,7 @@
 // SPDX-License-Identifier: LGPL-2.1+ OR MIT
 
 #[derive(ParseBytes)]
-struct Efs {
+struct FuStructEfs {
     signature: u32le = 0x55aa55aa,
     reserved: [u32le; 4],
     psp_dir_loc: u32le,
@@ -15,7 +15,7 @@ struct Efs {
 }
 
 #[derive(ValidateBytes, Getters)]
-struct PspDir {
+struct FuStructPspDir {
     cookie: [char; 4] == "$PSP",
     checksum: u32le,
     total_entries: u32le,
@@ -23,14 +23,14 @@ struct PspDir {
 }
 
 #[derive(ParseBytes)]
-struct PspDirTable {
+struct FuStructPspDirTable {
     fw_id: u32le,
     size: u32le,
     loc: u64le,
 }
 
 #[derive(ParseBytes)]
-struct ImageSlotHeader {
+struct FuStructImageSlotHeader {
     checksum: u32le,
     boot_priority: u32le,
     update_retries: u32le,
@@ -44,7 +44,7 @@ struct ImageSlotHeader {
 }
 
 #[repr(u8)]
-enum Fwid {
+enum FuFwid {
     AtomCsm = 0x1,
     PartitionAL2 = 0x014D,
     PartitionBL2 = 0x014E,
