@@ -122,9 +122,3 @@ fu_analogix_firmware_class_init(FuAnalogixFirmwareClass *klass)
 	FuFirmwareClass *klass_firmware = FU_FIRMWARE_CLASS(klass);
 	klass_firmware->parse = fu_analogix_firmware_parse;
 }
-
-FuFirmware *
-fu_analogix_firmware_new(void)
-{
-	return FU_FIRMWARE(g_object_new(FU_TYPE_ANALOGIX_FIRMWARE, NULL));
-}
