@@ -25,7 +25,7 @@ fu_android_boot_plugin_constructed(GObject *obj)
 {
 	FuPlugin *plugin = FU_PLUGIN(obj);
 	fu_plugin_add_device_gtype(plugin, FU_TYPE_ANDROID_BOOT_DEVICE);
-	fu_plugin_add_udev_subsystem(plugin, "block");
+	fu_plugin_add_device_udev_subsystem(plugin, "block");
 }
 
 static void
