@@ -24,13 +24,13 @@ static void
 fu_ata_plugin_constructed(GObject *obj)
 {
 	FuPlugin *plugin = FU_PLUGIN(obj);
-	fu_plugin_add_udev_subsystem(plugin, "block");
+	fu_plugin_add_device_udev_subsystem(plugin, "block");
 	fu_plugin_add_device_gtype(plugin, FU_TYPE_ATA_DEVICE);
 }
 
 static void
 fu_ata_plugin_class_init(FuAtaPluginClass *klass)
 {
-	GObjectClass *object_class = G_OBJECT_CLASS(klass);
-	object_class->constructed = fu_ata_plugin_constructed;
+	FuPluginClass *plugin_class = FU_PLUGIN_CLASS(klass);
+	plugin_class->constructed = fu_ata_plugin_constructed;
 }
