@@ -2,7 +2,7 @@
  * Copyright (C) 2018 Evan Lojewski
  * Copyright (C) 2020 Richard Hughes <richard@hughsie.com>
  *
- * SPDX-License-Identifier: GPL-2+
+ * SPDX-License-Identifier: LGPL-2.1+
  */
 
 #include "config.h"
@@ -618,7 +618,7 @@ fu_bcm57xx_device_open(FuDevice *device, GError **error)
 			    G_IO_ERROR_NOT_SUPPORTED,
 			    "failed to open socket: %s",
 #ifdef HAVE_ERRNO_H
-			    strerror(errno));
+			    g_strerror(errno));
 #else
 			    "unspecified error");
 #endif
