@@ -6,8 +6,6 @@
 
 #include "config.h"
 
-#include <fwupdplugin.h>
-
 #include "fu-bcm57xx-common.h"
 #include "fu-bcm57xx-dict-image.h"
 
@@ -48,7 +46,7 @@ fu_bcm57xx_dict_image_parse(FuFirmware *firmware,
 	return TRUE;
 }
 
-static GBytes *
+static GByteArray *
 fu_bcm57xx_dict_image_write(FuFirmware *firmware, GError **error)
 {
 	const guint8 *buf;
@@ -70,7 +68,7 @@ fu_bcm57xx_dict_image_write(FuFirmware *firmware, GError **error)
 	/* add CRC */
 	crc = fu_bcm57xx_nvram_crc(buf, bufsz);
 	fu_byte_array_append_uint32(blob, crc, G_LITTLE_ENDIAN);
-	return g_byte_array_free_to_bytes(g_steal_pointer(&blob));
+	return g_steal_pointer(&blob);
 }
 
 static gboolean
