@@ -25,10 +25,16 @@ fu_bcm57xx_plugin_init(FuBcm57XxPlugin *self)
 }
 
 static void
-fu_bcm57xx_plugin_constructed(GObject *obj)
+fu_bcm57xx_plugin_object_constructed(GObject *obj)
 {
 	FuPlugin *plugin = FU_PLUGIN(obj);
 	fu_plugin_set_name(plugin, "bcm57xx");
+}
+
+static void
+fu_bcm57xx_plugin_constructed(GObject *obj)
+{
+	FuPlugin *plugin = FU_PLUGIN(obj);
 	fu_plugin_add_udev_subsystem(plugin, "pci");
 	fu_plugin_add_device_gtype(plugin, FU_TYPE_BCM57XX_DEVICE);
 	fu_plugin_add_firmware_gtype(plugin, NULL, FU_TYPE_BCM57XX_FIRMWARE);
@@ -41,6 +47,8 @@ fu_bcm57xx_plugin_constructed(GObject *obj)
 static void
 fu_bcm57xx_plugin_class_init(FuBcm57XxPluginClass *klass)
 {
+	FuPluginClass *plugin_class = FU_PLUGIN_CLASS(klass);
 	GObjectClass *object_class = G_OBJECT_CLASS(klass);
-	object_class->constructed = fu_bcm57xx_plugin_constructed;
+	object_class->constructed = fu_bcm57xx_plugin_object_constructed;
+	plugin_class->constructed = fu_bcm57xx_plugin_constructed;
 }
