@@ -3,14 +3,14 @@
 // SPDX-License-Identifier: LGPL-2.1+
 
 #[derive(New, Parse)]
-struct CfuGetVersionRsp {
+struct FuStructCfuGetVersionRsp {
     component_cnt: u8,
     _reserved: u16le,
     flags: u8,
 }
 
 #[derive(New, Parse)]
-struct CfuGetVersionRspComponent {
+struct FuStructCfuGetVersionRspComponent {
     fw_version: u32le,
     flags: u8,
     component_id: u8,
@@ -19,7 +19,7 @@ struct CfuGetVersionRspComponent {
 
 #[derive(ToString)]
 #[repr(u8)]
-enum CfuOfferInfoCode {
+enum FuCfuOfferInfoCode {
     StartEntireTransaction = 0x00,
     StartOfferList = 0x01,
     EndOfferList = 0x02,
@@ -27,7 +27,7 @@ enum CfuOfferInfoCode {
 
 #[derive(ToString)]
 #[repr(u8)]
-enum CfuRrCode {
+enum FuCfuRrCode {
     OfferRejectOldFirmware = 0x00,
     OfferRejectInvComponent = 0x01,
     UpdateOfferSwapPending = 0x02,
@@ -40,7 +40,7 @@ enum CfuRrCode {
 
 #[derive(ToString)]
 #[repr(u8)]
-enum CfuOfferStatus {
+enum FuCfuOfferStatus {
     Skip = 0x00,
     Accept = 0x01,
     Reject = 0x02,
@@ -50,8 +50,8 @@ enum CfuOfferStatus {
 }
 
 #[derive(New)]
-struct CfuOfferInfoReq {
-    code: CfuOfferInfoCode,
+struct FuStructCfuOfferInfoReq {
+    code: FuCfuOfferInfoCode,
     _reserved1: u8,
     component_id: u8 == 0xFF,
     token: u8 == 0xDE, // chosen by dice roll
@@ -59,18 +59,18 @@ struct CfuOfferInfoReq {
 }
 
 #[derive(Parse)]
-struct CfuOfferRsp {
+struct FuStructCfuOfferRsp {
     _reserved1: [u8; 3],
     token: u8,
     _reserved2: [u8; 4],
-    rr_code: CfuRrCode,
+    rr_code: FuCfuRrCode,
     _reserved3: [u8; 3],
-    status: CfuOfferStatus,
+    status: FuCfuOfferStatus,
     _reserved3: [u8; 3],
 }
 
 #[repr(u8)]
-enum CfuContentFlag {
+enum FuCfuContentFlag {
     Verify = 0x08,
     TestReplaceFilesystem = 0x20,
     LastBlock = 0x40,
@@ -79,7 +79,7 @@ enum CfuContentFlag {
 
 #[derive(ToString)]
 #[repr(u8)]
-enum CfuContentStatus {
+enum FuCfuContentStatus {
     Success = 0x00,
     ErrorPrepare = 0x01,
     ErrorWrite = 0x02,
@@ -95,18 +95,18 @@ enum CfuContentStatus {
 }
 
 #[derive(New, Getters)]
-struct CfuContentReq {
-    flags: CfuContentFlag,
+struct FuStructCfuContentReq {
+    flags: FuCfuContentFlag,
     data_length: u8,
     seq_number: u16le,
     address: u32le,
 }
 
 #[derive(Parse)]
-struct CfuContentRsp {
+struct FuStructCfuContentRsp {
     seq_number: u16le,
     _reserved1: u16le,
-    status: CfuContentStatus,
+    status: FuCfuContentStatus,
     _reserved2: [u8; 3],
     _reserved3: [u8; 4],
     _reserved4: [u8; 4],
