@@ -30,6 +30,6 @@ fu_colorhug_plugin_constructed(GObject *obj)
 static void
 fu_colorhug_plugin_class_init(FuColorhugPluginClass *klass)
 {
-	GObjectClass *object_class = G_OBJECT_CLASS(klass);
-	object_class->constructed = fu_colorhug_plugin_constructed;
+	FuPluginClass *plugin_class = FU_PLUGIN_CLASS(klass);
+	plugin_class->constructed = fu_colorhug_plugin_constructed;
 }
