@@ -15,8 +15,6 @@
 
 #include "config.h"
 
-#include <fwupdplugin.h>
-
 #include "fu-dell-dock-common.h"
 #include "fu-dell-dock-i2c-ec.h"
 
@@ -45,17 +43,3 @@ fu_dell_dock_set_power(FuDevice *device, guint8 target, gboolean enabled, GError
 
 	return fu_dell_dock_ec_modify_lock(parent, target, enabled, error);
 }
-
-void
-fu_dell_dock_will_replug(FuDevice *device)
-{
-	guint64 timeout = fu_device_get_install_duration(device);
-
-	g_return_if_fail(FU_IS_DEVICE(device));
-
-	g_debug("Activated %" G_GUINT64_FORMAT "s replug delay for %s",
-		timeout,
-		fu_device_get_name(device));
-	fu_device_set_remove_delay(device, timeout * 1000);
-	fu_device_add_flag(device, FWUPD_DEVICE_FLAG_WAIT_FOR_REPLUG);
-}
