@@ -16,8 +16,6 @@
 
 #include "config.h"
 
-#include <fwupdplugin.h>
-
 #include <string.h>
 
 #include "fu-dell-dock-common.h"
@@ -1063,7 +1061,7 @@ fu_dell_dock_mst_write_fw(FuDevice *device,
 					  data[self->blob_major_offset],
 					  data[self->blob_minor_offset],
 					  data[self->blob_build_offset]);
-	g_debug("writing MST firmware version %s", dynamic_version);
+	g_info("writing MST firmware version %s", dynamic_version);
 
 	/* enable remote control */
 	if (!fu_dell_dock_mst_enable_remote_control(device, error))
