@@ -11,26 +11,26 @@
 #include "fu-dell-kestrel-rtshub-struct.h"
 #include "fu-dell-kestrel-rtshub.h"
 
-struct _FuDellKestrelRtsHub {
+struct _FuDellKestrelRtshub {
 	FuHidDevice parent_instance;
 	FuDellDockBaseType dock_type;
 	gboolean fw_auth;
 	gboolean dual_bank;
 };
 
-G_DEFINE_TYPE(FuDellKestrelRtsHub, fu_dell_kestrel_rtshub, FU_TYPE_HID_DEVICE)
+G_DEFINE_TYPE(FuDellKestrelRtshub, fu_dell_kestrel_rtshub, FU_TYPE_HID_DEVICE)
 
 static void
 fu_dell_kestrel_rtshub_to_string(FuDevice *device, guint idt, GString *str)
 {
-	FuDellKestrelRtsHub *self = FU_DELL_KESTREL_RTSHUB(device);
+	FuDellKestrelRtshub *self = FU_DELL_KESTREL_RTSHUB(device);
 	fu_string_append_kb(str, idt, "FwAuth", self->fw_auth);
 	fu_string_append_kb(str, idt, "DualBank", self->dual_bank);
 	fu_string_append_kb(str, idt, "DockType", self->dock_type);
 }
 
 static gboolean
-fu_dell_kestrel_rtshub_set_clock_mode(FuDellKestrelRtsHub *self, gboolean enable, GError **error)
+fu_dell_kestrel_rtshub_set_clock_mode(FuDellKestrelRtshub *self, gboolean enable, GError **error)
 {
 	g_autoptr(GByteArray) cmd_buf = fu_struct_rtshub_hid_cmd_buf_new();
 
@@ -53,7 +53,7 @@ fu_dell_kestrel_rtshub_set_clock_mode(FuDellKestrelRtsHub *self, gboolean enable
 }
 
 static gboolean
-fu_dell_kestrel_rtshub_erase_spare_bank(FuDellKestrelRtsHub *self, GError **error)
+fu_dell_kestrel_rtshub_erase_spare_bank(FuDellKestrelRtshub *self, GError **error)
 {
 	g_autoptr(GByteArray) cmd_buf = fu_struct_rtshub_hid_cmd_buf_new();
 
@@ -76,7 +76,7 @@ fu_dell_kestrel_rtshub_erase_spare_bank(FuDellKestrelRtsHub *self, GError **erro
 }
 
 static gboolean
-fu_dell_kestrel_rtshub_verify_update_fw(FuDellKestrelRtsHub *self,
+fu_dell_kestrel_rtshub_verify_update_fw(FuDellKestrelRtshub *self,
 					FuProgress *progress,
 					GError **error)
 {
@@ -116,7 +116,7 @@ fu_dell_kestrel_rtshub_verify_update_fw(FuDellKestrelRtsHub *self,
 }
 
 static gboolean
-fu_dell_kestrel_rtshub_reset_device(FuDellKestrelRtsHub *self, GError **error)
+fu_dell_kestrel_rtshub_reset_device(FuDellKestrelRtshub *self, GError **error)
 {
 	g_autoptr(GByteArray) cmd_buf = fu_struct_rtshub_hid_cmd_buf_new();
 
@@ -138,7 +138,7 @@ fu_dell_kestrel_rtshub_reset_device(FuDellKestrelRtsHub *self, GError **error)
 }
 
 static gboolean
-fu_dell_kestrel_rtshub_write_flash(FuDellKestrelRtsHub *self,
+fu_dell_kestrel_rtshub_write_flash(FuDellKestrelRtshub *self,
 				   guint32 addr,
 				   const guint8 *data,
 				   guint16 data_sz,
@@ -177,8 +177,7 @@ fu_dell_kestrel_rtshub_write_firmware(FuDevice *device,
 				      FwupdInstallFlags flags,
 				      GError **error)
 {
-	FuDellKestrelRtsHub *self = FU_DELL_KESTREL_RTSHUB(device);
-	FuDevice *parent = fu_device_get_parent(device);
+	FuDellKestrelRtshub *self = FU_DELL_KESTREL_RTSHUB(device);
 	g_autoptr(GBytes) fw = NULL;
 	g_autoptr(FuChunkArray) chunks = NULL;
 
@@ -241,11 +240,11 @@ fu_dell_kestrel_rtshub_write_firmware(FuDevice *device,
 	fu_progress_step_done(progress);
 
 	/* non-uod: reset the device immediately */
-	if (!fu_device_has_flag(parent, FWUPD_DEVICE_FLAG_USABLE_DURING_UPDATE)) {
+	if (!fu_device_has_flag(device, FWUPD_DEVICE_FLAG_USABLE_DURING_UPDATE)) {
 		/* rts5g2 only */
 		if (fu_usb_device_get_pid(FU_USB_DEVICE(device)) == DELL_KESTREL_USB_RTS5_G2_PID) {
 			if (!fu_dell_kestrel_rtshub_reset_device(self, error)) {
-				g_prefix_error(error, "failed to reset rts5g2 device: ");
+				g_prefix_error_literal(error, "failed to reset rts5g2 device: ");
 				return FALSE;
 			}
 			fu_device_add_flag(device, FWUPD_DEVICE_FLAG_WAIT_FOR_REPLUG);
@@ -259,7 +258,7 @@ fu_dell_kestrel_rtshub_write_firmware(FuDevice *device,
 static gboolean
 fu_dell_kestrel_rtshub_get_status(FuDevice *device, GError **error)
 {
-	FuDellKestrelRtsHub *self = FU_DELL_KESTREL_RTSHUB(device);
+	FuDellKestrelRtshub *self = FU_DELL_KESTREL_RTSHUB(device);
 	g_autofree gchar *version = NULL;
 	g_autoptr(GByteArray) cmd_buf = fu_struct_rtshub_hid_cmd_buf_new();
 
@@ -301,7 +300,7 @@ fu_dell_kestrel_rtshub_get_status(FuDevice *device, GError **error)
 static gboolean
 fu_dell_kestrel_rtshub_setup(FuDevice *device, GError **error)
 {
-	FuDellKestrelRtsHub *self = FU_DELL_KESTREL_RTSHUB(device);
+	FuDellKestrelRtshub *self = FU_DELL_KESTREL_RTSHUB(device);
 
 	/* FuUsbDevice->setup */
 	if (!FU_DEVICE_CLASS(fu_dell_kestrel_rtshub_parent_class)->setup(device, error))
@@ -323,7 +322,7 @@ static gboolean
 fu_dell_kestrel_rtshub_probe(FuDevice *device, GError **error)
 {
 	g_autofree const gchar *logical_id = NULL;
-	FuDellKestrelRtsHub *self = FU_DELL_KESTREL_RTSHUB(device);
+	FuDellKestrelRtshub *self = FU_DELL_KESTREL_RTSHUB(device);
 
 	/* not interesting */
 	if (fu_usb_device_get_vid(FU_USB_DEVICE(device)) != DELL_VID) {
@@ -366,19 +365,6 @@ fu_dell_kestrel_rtshub_probe(FuDevice *device, GError **error)
 	return TRUE;
 }
 
-static gboolean
-fu_dell_kestrel_rtshub_open(FuDevice *device, GError **error)
-{
-	FuDevice *parent = fu_device_get_parent(device);
-
-	if (!FU_DEVICE_CLASS(fu_dell_kestrel_rtshub_parent_class)->open(device, error))
-		return FALSE;
-
-	if (parent != NULL)
-		return fu_device_open(parent, error);
-	return TRUE;
-}
-
 static void
 fu_dell_kestrel_rtshub_set_progress(FuDevice *self, FuProgress *progress)
 {
@@ -391,7 +377,7 @@ fu_dell_kestrel_rtshub_set_progress(FuDevice *self, FuProgress *progress)
 }
 
 static void
-fu_dell_kestrel_rtshub_init(FuDellKestrelRtsHub *self)
+fu_dell_kestrel_rtshub_init(FuDellKestrelRtshub *self)
 {
 	fu_device_add_protocol(FU_DEVICE(self), "com.dell.kestrel");
 	fu_device_add_flag(FU_DEVICE(self), FWUPD_DEVICE_FLAG_UPDATABLE);
@@ -406,7 +392,7 @@ fu_dell_kestrel_rtshub_init(FuDellKestrelRtsHub *self)
 }
 
 static void
-fu_dell_kestrel_rtshub_class_init(FuDellKestrelRtsHubClass *klass)
+fu_dell_kestrel_rtshub_class_init(FuDellKestrelRtshubClass *klass)
 {
 	FuDeviceClass *device_class = FU_DEVICE_CLASS(klass);
 	device_class->to_string = fu_dell_kestrel_rtshub_to_string;
@@ -414,15 +400,17 @@ fu_dell_kestrel_rtshub_class_init(FuDellKestrelRtsHubClass *klass)
 	device_class->probe = fu_dell_kestrel_rtshub_probe;
 	device_class->write_firmware = fu_dell_kestrel_rtshub_write_firmware;
 	device_class->set_progress = fu_dell_kestrel_rtshub_set_progress;
-	device_class->open = fu_dell_kestrel_rtshub_open;
 }
 
-FuDellKestrelRtsHub *
-fu_dell_kestrel_rtshub_new(FuUsbDevice *device, FuDellDockBaseType dock_type)
+FuDellKestrelRtshub *
+fu_dell_kestrel_rtshub_new(FuUsbDevice *device, FuDellDockBaseType dock_type, gboolean uod)
 {
-	FuDellKestrelRtsHub *self = g_object_new(FU_TYPE_DELL_KESTREL_RTSHUB, NULL);
+	FuDellKestrelRtshub *self = g_object_new(FU_TYPE_DELL_KESTREL_RTSHUB, NULL);
 
 	fu_device_incorporate(FU_DEVICE(self), FU_DEVICE(device));
 	self->dock_type = dock_type;
+
+	if (uod)
+		fu_device_add_flag(FU_DEVICE(self), FWUPD_DEVICE_FLAG_USABLE_DURING_UPDATE);
 	return self;
 }
