@@ -345,7 +345,7 @@ fu_dfu_tool_read_alt(FuDfuTool *self, gchar **values, GError **error)
 	locker = fu_device_locker_new(device, error);
 	if (locker == NULL)
 		return FALSE;
-	if (!fu_dfu_device_refresh(device, error))
+	if (!fu_dfu_device_refresh(device, 0, error))
 		return FALSE;
 
 	/* set up progress */
@@ -445,7 +445,7 @@ fu_dfu_tool_read(FuDfuTool *self, gchar **values, GError **error)
 	locker = fu_device_locker_new(device, error);
 	if (locker == NULL)
 		return FALSE;
-	if (!fu_dfu_device_refresh(device, error))
+	if (!fu_dfu_device_refresh(device, 0, error))
 		return FALSE;
 
 	/* APP -> DFU */
@@ -535,7 +535,7 @@ fu_dfu_tool_write_alt(FuDfuTool *self, gchar **values, GError **error)
 	locker = fu_device_locker_new(device, error);
 	if (locker == NULL)
 		return FALSE;
-	if (!fu_dfu_device_refresh(device, error))
+	if (!fu_dfu_device_refresh(device, 0, error))
 		return FALSE;
 
 	/* set up progress */
@@ -652,7 +652,7 @@ fu_dfu_tool_write(FuDfuTool *self, gchar **values, GError **error)
 	locker = fu_device_locker_new(device, error);
 	if (locker == NULL)
 		return FALSE;
-	if (!fu_dfu_device_refresh(device, error))
+	if (!fu_dfu_device_refresh(device, 0, error))
 		return FALSE;
 
 	/* APP -> DFU */
@@ -760,6 +760,11 @@ main(int argc, char *argv[])
 	bind_textdomain_codeset(GETTEXT_PACKAGE, "UTF-8");
 	textdomain(GETTEXT_PACKAGE);
 
+#ifndef SUPPORTED_BUILD
+	/* make critical warnings fatal */
+	(void)g_setenv("G_DEBUG", "fatal-criticals", FALSE);
+#endif
+
 	/* add commands */
 	self->cmd_array = g_ptr_array_new_with_free_func((GDestroyNotify)fu_dfu_tool_item_free);
 	fu_dfu_tool_add(self->cmd_array,
