@@ -34,6 +34,6 @@ fu_hailuck_plugin_constructed(GObject *obj)
 static void
 fu_hailuck_plugin_class_init(FuHailuckPluginClass *klass)
 {
-	GObjectClass *object_class = G_OBJECT_CLASS(klass);
-	object_class->constructed = fu_hailuck_plugin_constructed;
+	FuPluginClass *plugin_class = FU_PLUGIN_CLASS(klass);
+	plugin_class->constructed = fu_hailuck_plugin_constructed;
 }
