@@ -91,25 +91,20 @@ fu_igsc_oprom_firmware_match_device(FuIgscOpromFirmware *self,
 static gboolean
 fu_igsc_oprom_firmware_parse_extension(FuIgscOpromFirmware *self, FuFirmware *fw, GError **error)
 {
-	const guint8 *buf;
-	gsize bufsz = 0;
 	g_autoptr(GBytes) blob = NULL;
 
 	/* get data */
 	blob = fu_firmware_get_bytes(fw, error);
 	if (blob == NULL)
 		return FALSE;
-	buf = g_bytes_get_data(blob, &bufsz);
-
 	if (fu_firmware_get_idx(fw) == MFT_EXT_TYPE_DEVICE_TYPE) {
-		for (gsize offset = 0; offset < bufsz;
+		for (gsize offset = 0; offset < g_bytes_get_size(blob);
 		     offset += FU_STRUCT_IGSC_OPROM_SUBSYSTEM_DEVICE_ID_SIZE) {
 			g_autofree FuIgscFwdataDeviceInfo *info = g_new0(FuIgscFwdataDeviceInfo, 1);
 			g_autoptr(GByteArray) st = NULL;
-			st = fu_struct_igsc_oprom_subsystem_device_id_parse(buf,
-									    bufsz,
-									    offset,
-									    error);
+			st = fu_struct_igsc_oprom_subsystem_device_id_parse_bytes(blob,
+										  offset,
+										  error);
 			if (st == NULL)
 				return FALSE;
 			info->subsys_vendor_id =
@@ -119,14 +114,13 @@ fu_igsc_oprom_firmware_parse_extension(FuIgscOpromFirmware *self, FuFirmware *fw
 			g_ptr_array_add(self->device_infos, g_steal_pointer(&info));
 		}
 	} else if (fu_firmware_get_idx(fw) == MFT_EXT_TYPE_DEVICE_ID_ARRAY) {
-		for (gsize offset = 0; offset < bufsz;
+		for (gsize offset = 0; offset < g_bytes_get_size(blob);
 		     offset += FU_STRUCT_IGSC_OPROM_SUBSYSTEM_DEVICE4_ID_SIZE) {
 			g_autofree FuIgscFwdataDeviceInfo *info = g_new0(FuIgscFwdataDeviceInfo, 1);
 			g_autoptr(GByteArray) st = NULL;
-			st = fu_struct_igsc_oprom_subsystem_device4_id_parse(buf,
-									     bufsz,
-									     offset,
-									     error);
+			st = fu_struct_igsc_oprom_subsystem_device4_id_parse_bytes(blob,
+										   offset,
+										   error);
 			if (st == NULL)
 				return FALSE;
 			info->vendor_id =
