@@ -6,8 +6,6 @@
 
 #include "config.h"
 
-#include <fwupdplugin.h>
-
 #include "fu-intel-me-common.h"
 #include "fu-intel-me-heci-device.h"
 
@@ -176,11 +174,25 @@ fu_intel_me_heci_device_read_file_ex(FuIntelMeHeciDevice *self,
 	return fu_intel_me_heci_device_read_file_response(buf_res, datasz_req, error);
 }
 
+static void
+fu_intel_me_heci_device_version_notify_cb(FuDevice *device, GParamSpec *pspec, gpointer user_data)
+{
+	if (fu_device_has_private_flag(device, FU_INTEL_ME_HECI_DEVICE_FLAG_LEAKED_KM))
+		fu_device_inhibit(device, "leaked-km", "Provisioned with a leaked private key");
+}
+
 static void
 fu_intel_me_heci_device_init(FuIntelMeHeciDevice *self)
 {
 	fu_device_add_flag(FU_DEVICE(self), FWUPD_DEVICE_FLAG_INTERNAL);
 	fu_device_add_icon(FU_DEVICE(self), "computer");
+	fu_device_register_private_flag(FU_DEVICE(self),
+					FU_INTEL_ME_HECI_DEVICE_FLAG_LEAKED_KM,
+					"leaked-km");
+	g_signal_connect(FWUPD_DEVICE(self),
+			 "notify::private-flags",
+			 G_CALLBACK(fu_intel_me_heci_device_version_notify_cb),
+			 NULL);
 }
 
 static void
