@@ -2,7 +2,7 @@
 // SPDX-License-Identifier: LGPL-2.1+
 
 #[derive(ToString)]
-enum LogitechBulkcontrollerDeviceState {
+enum FuLogitechBulkcontrollerDeviceState {
     Unknown = -1,
     Offline,
     Online,
@@ -13,7 +13,7 @@ enum LogitechBulkcontrollerDeviceState {
 }
 
 #[derive(ToString)]
-enum LogitechBulkcontrollerUpdateState {
+enum FuLogitechBulkcontrollerUpdateState {
     Unknown = -1,
     Current,
     Available,
@@ -27,7 +27,7 @@ enum LogitechBulkcontrollerUpdateState {
 
 #[repr(u32le)]
 #[derive(ToString)]
-enum LogitechBulkcontrollerCmd {
+enum FuLogitechBulkcontrollerCmd {
     CheckBuffersize = 0xCC00,
     Init = 0xCC01,
     StartTransfer = 0xCC02,
@@ -43,32 +43,32 @@ enum LogitechBulkcontrollerCmd {
 }
 
 #[derive(New, ToString, Getters)]
-struct LogitechBulkcontrollerSendSyncReq {
-    cmd: LogitechBulkcontrollerCmd,
+struct FuStructLogitechBulkcontrollerSendSyncReq {
+    cmd: FuLogitechBulkcontrollerCmd,
     payload_length: u32le,
     sequence_id: u32le,
 }
 #[derive(Parse)]
-struct LogitechBulkcontrollerSendSyncRes {
-    cmd: LogitechBulkcontrollerCmd,
+struct FuStructLogitechBulkcontrollerSendSyncRes {
+    cmd: FuLogitechBulkcontrollerCmd,
     payload_length: u32le,
     sequence_id: u32le,
 }
 
 #[derive(New)]
-struct LogitechBulkcontrollerUpdateReq {
-    cmd: LogitechBulkcontrollerCmd,
+struct FuStructLogitechBulkcontrollerUpdateReq {
+    cmd: FuLogitechBulkcontrollerCmd,
     payload_length: u32le,
 }
 
 #[derive(Getters)]
-struct LogitechBulkcontrollerUpdateRes {
-    cmd: LogitechBulkcontrollerCmd,
+struct FuStructLogitechBulkcontrollerUpdateRes {
+    cmd: FuLogitechBulkcontrollerCmd,
     _payload_length: u32le,
-    cmd_req: LogitechBulkcontrollerCmd,
+    cmd_req: FuLogitechBulkcontrollerCmd,
 }
 
-enum LogitechBulkcontrollerChecksumType {
+enum FuLogitechBulkcontrollerChecksumType {
     Sha256,
     Sha512,
     Md5,
