@@ -8,17 +8,17 @@
 
 #include <glib.h>
 
-#define FU_UNIFYING_DEVICE_VID 0x046d
+#define FU_LOGITECH_HIDPP_DEVICE_VID 0x046d
 
-#define FU_UNIFYING_DEVICE_PID_RUNTIME		      0xc52b
-#define FU_UNIFYING_DEVICE_PID_BOOTLOADER_NORDIC      0xaaaa
-#define FU_UNIFYING_DEVICE_PID_BOOTLOADER_NORDIC_PICO 0xaaae
-#define FU_UNIFYING_DEVICE_PID_BOOTLOADER_TEXAS	      0xaaac
-#define FU_UNIFYING_DEVICE_PID_BOOTLOADER_TEXAS_PICO  0xaaad
-#define FU_UNIFYING_DEVICE_PID_BOOTLOADER_BOLT	      0xab07
+#define FU_LOGITECH_HIDPP_DEVICE_PID_RUNTIME		    0xc52b
+#define FU_LOGITECH_HIDPP_DEVICE_PID_BOOTLOADER_NORDIC	    0xaaaa
+#define FU_LOGITECH_HIDPP_DEVICE_PID_BOOTLOADER_NORDIC_PICO 0xaaae
+#define FU_LOGITECH_HIDPP_DEVICE_PID_BOOTLOADER_TEXAS	    0xaaac
+#define FU_LOGITECH_HIDPP_DEVICE_PID_BOOTLOADER_TEXAS_PICO  0xaaad
+#define FU_LOGITECH_HIDPP_DEVICE_PID_BOOTLOADER_BOLT	    0xab07
 
 /* Signed firmware are very long to verify on the device */
-#define FU_UNIFYING_DEVICE_TIMEOUT_MS 30000
+#define FU_LOGITECH_HIDPP_DEVICE_TIMEOUT_MS 30000
 
 /* Polling intervals (ms) */
 #define FU_HIDPP_DEVICE_POLLING_INTERVAL	   30000
