@@ -9,8 +9,8 @@
 #include "fu-logitech-hidpp-runtime.h"
 
 #define FU_TYPE_HIDPP_RUNTIME_UNIFYING (fu_logitech_hidpp_runtime_unifying_get_type())
-G_DECLARE_FINAL_TYPE(FuLogitechHidPpRuntimeUnifying,
+G_DECLARE_FINAL_TYPE(FuLogitechHidppRuntimeUnifying,
 		     fu_logitech_hidpp_runtime_unifying,
 		     FU,
 		     HIDPP_RUNTIME_UNIFYING,
-		     FuLogitechHidPpRuntime)
+		     FuLogitechHidppRuntime)
