@@ -2,7 +2,7 @@
 // SPDX-License-Identifier: LGPL-2.1+
 
 #[derive(Parse)]
-struct AudioSerialNumber {
+struct FuStructAudioSerialNumber {
     mac_address: [u8; 6],
     pid: u16le,
     year: u16le,
@@ -11,14 +11,14 @@ struct AudioSerialNumber {
 }
 
 #[repr(u16le)]
-enum UsbCmdId {
+enum FuUsbCmdId {
     Init = 0xCC01,
     FirmwareDownload = 0xCC03,
     ReadVersion = 0xCC07,
 }
 
 #[repr(u16le)]
-enum UsbCmdStatus {
+enum FuUsbCmdStatus {
     Ok = 0x0, // inferred
     Req = 0xFFFF,
     InitReq = 0xBEEF,
@@ -26,55 +26,55 @@ enum UsbCmdStatus {
 }
 
 #[derive(New)]
-struct UsbInitRequest {
-    id: UsbCmdId == Init,
-    status: UsbCmdStatus == InitReq,
+struct FuStructUsbInitRequest {
+    id: FuUsbCmdId == Init,
+    status: FuUsbCmdStatus == InitReq,
     len: u32le == 0,
 }
 
 #[derive(Parse)]
-struct UsbInitResponse {
-    id: UsbCmdId == Init,
-    status: UsbCmdStatus == InitReqAck,
+struct FuStructUsbInitResponse {
+    id: FuUsbCmdId == Init,
+    status: FuUsbCmdStatus == InitReqAck,
     len: u32le == 0, // inferred
 }
 
 #[derive(New)]
-struct UsbFirmwareDownloadRequest {
-    id: UsbCmdId == FirmwareDownload,
-    status: UsbCmdStatus == Req,
+struct FuStructUsbFirmwareDownloadRequest {
+    id: FuUsbCmdId == FirmwareDownload,
+    status: FuUsbCmdStatus == Req,
     len: u32le,
     fw_version: [char; 16],
 }
 
 #[derive(Parse)]
-struct UsbFirmwareDownloadResponse {
-    id: UsbCmdId == FirmwareDownload,
-    status: UsbCmdStatus == Ok,
+struct FuStructUsbFirmwareDownloadResponse {
+    id: FuUsbCmdId == FirmwareDownload,
+    status: FuUsbCmdStatus == Ok,
     len: u32le,
 }
 
 #[derive(New)]
-struct UsbReadVersionRequest {
-    id: UsbCmdId == ReadVersion,
-    status: UsbCmdStatus == Req,
+struct FuStructUsbReadVersionRequest {
+    id: FuUsbCmdId == ReadVersion,
+    status: FuUsbCmdStatus == Req,
     len: u32le == 0,
 }
 
 #[repr(u32le)]
-enum UsbImageState {
+enum FuUsbImageState {
     New = 0x0,
     Valid = 0x1,
     Invalid = 0x2,
 }
 
 #[derive(Parse)]
-struct UsbReadVersionResponse {
+struct FuStructUsbReadVersionResponse {
     fw_version: [char; 16],
-    img_state: UsbImageState,
+    img_state: FuUsbImageState,
 }
 
 #[derive(Parse)]
-struct UsbProgressResponse {
+struct FuStructUsbProgressResponse {
     completed: u32le,
 }
