@@ -428,6 +428,29 @@ fu_nordic_hid_cfg_channel_is_cached_peer_connected(guint8 peer_cache_val)
 	return (peer_cache_val % 2) != 0;
 }
 
+static void
+fu_nordic_hid_cfg_channel_check_children_update_pending_cb(FuDevice *device,
+							   GParamSpec *pspec,
+							   gpointer user_data)
+{
+	FuNordicHidCfgChannel *self = FU_NORDIC_HID_CFG_CHANNEL(user_data);
+	GPtrArray *children = fu_device_get_children(FU_DEVICE(self));
+	gboolean update_pending = FALSE;
+
+	for (guint i = 0; i < children->len; i++) {
+		FuDevice *peer = g_ptr_array_index(children, i);
+		if (fu_device_has_internal_flag(peer, FU_DEVICE_INTERNAL_FLAG_UPDATE_PENDING)) {
+			update_pending = TRUE;
+			break;
+		}
+	}
+	if (update_pending) {
+		fu_device_add_problem(FU_DEVICE(self), FWUPD_DEVICE_PROBLEM_UPDATE_PENDING);
+	} else {
+		fu_device_remove_problem(FU_DEVICE(self), FWUPD_DEVICE_PROBLEM_UPDATE_PENDING);
+	}
+}
+
 static void
 fu_nordic_hid_cfg_channel_add_peer(FuNordicHidCfgChannel *self, guint8 peer_id)
 {
@@ -437,7 +460,9 @@ fu_nordic_hid_cfg_channel_add_peer(FuNordicHidCfgChannel *self, guint8 peer_id)
 	peer = fu_nordic_hid_cfg_channel_new(peer_id, self);
 
 	/* ensure that the general quirk content for Nordic HID devices is applied */
-	fu_device_add_instance_id(FU_DEVICE(peer), "HIDRAW\\VEN_1915");
+	fu_device_add_instance_id_full(FU_DEVICE(peer),
+				       "HIDRAW\\VEN_1915",
+				       FU_DEVICE_INSTANCE_FLAG_QUIRKS);
 
 	if (!fu_device_setup(FU_DEVICE(peer), &error_local)) {
 		g_debug("failed to discover peer 0x%02x: %s", peer_id, error_local->message);
@@ -445,6 +470,13 @@ fu_nordic_hid_cfg_channel_add_peer(FuNordicHidCfgChannel *self, guint8 peer_id)
 	}
 
 	g_debug("peer 0x%02x discovered", peer_id);
+
+	/* if any of the peripherals have a pending update, inhibit the dongle */
+	g_signal_connect(FU_DEVICE(peer),
+			 "notify::internal-flags",
+			 G_CALLBACK(fu_nordic_hid_cfg_channel_check_children_update_pending_cb),
+			 self);
+
 	fu_device_add_child(FU_DEVICE(self), FU_DEVICE(peer));
 	/* prohibit to close parent's communication descriptor */
 	fu_device_add_internal_flag(FU_DEVICE(peer), FU_DEVICE_INTERNAL_FLAG_USE_PARENT_FOR_OPEN);
@@ -609,7 +641,6 @@ fu_nordic_hid_cfg_channel_update_peers(FuNordicHidCfgChannel *self,
 	gboolean peers_supported = FALSE;
 	guint8 peer_id;
 	guint cnt = 0;
-	g_autoptr(GError) error_local = NULL;
 
 	if (!fu_nordic_hid_cfg_channel_index_peers_cmd(self, &peers_supported, error))
 		return FALSE;
@@ -1507,18 +1538,18 @@ fu_nordic_hid_cfg_channel_write_firmware_blob(FuNordicHidCfgChannel *self,
 					      GError **error)
 {
 	g_autoptr(FuNordicCfgChannelDfuInfo) dfu_info = g_new0(FuNordicCfgChannelDfuInfo, 1);
-	g_autoptr(GPtrArray) chunks = NULL;
+	g_autoptr(FuChunkArray) chunks = NULL;
 
 	if (!fu_nordic_hid_cfg_channel_dfu_sync(self, dfu_info, DFU_STATE_ACTIVE, error))
 		return FALSE;
 
-	chunks = fu_chunk_array_new_from_bytes(blob, 0, 0, dfu_info->sync_buffer_size);
+	chunks = fu_chunk_array_new_from_bytes(blob, 0, dfu_info->sync_buffer_size);
 	fu_progress_set_id(progress, G_STRLOC);
-	fu_progress_set_steps(progress, chunks->len);
+	fu_progress_set_steps(progress, fu_chunk_array_length(chunks));
 
-	for (guint i = 0; i < chunks->len; i++) {
-		FuChunk *chk = g_ptr_array_index(chunks, i);
-		gboolean is_last = (i == chunks->len - 1);
+	for (guint i = 0; i < fu_chunk_array_length(chunks); i++) {
+		g_autoptr(FuChunk) chk = fu_chunk_array_index(chunks, i);
+		gboolean is_last = (i == fu_chunk_array_length(chunks) - 1);
 		if (!fu_nordic_hid_cfg_channel_write_firmware_chunk(self, chk, is_last, error)) {
 			g_prefix_error(error, "chunk %u: ", fu_chunk_get_idx(chk));
 			return FALSE;
